@@ -117,6 +117,12 @@ class ModelService(object):
         graph = CHGraph(graph_client)
         self.use_graph(graph_name, db)
 
+        """
+        获取时间限制条件
+        """
+        start_time = data.get("startTime")
+        end_time = data.get("endTime")
+
         rest = []
         edges = self.graph_cfg.get("edges")
         vertexes = self.graph_cfg.get("vertexes")
@@ -125,7 +131,7 @@ class ModelService(object):
             edge_conditions = data.get("edgeConditions") or []
             for condition in edge_conditions:
                 edge_condition_dict, edge_order_dict, special_sql_dict = condition_operation.\
-                    conditional_operation_by_one(condition, edges)
+                    conditional_operation_by_one(condition, edges, start_time, end_time)
                 if "sql" in special_sql_dict:
                     res = execute_graph_sql(graph, special_sql_dict.get("sql"), type=condition.get("type"))
                     rest.append(res)
@@ -133,7 +139,7 @@ class ModelService(object):
             node_conditions = data.get("nodeConditions") or []
             for condition in node_conditions:
                 node_condition_dict, node_order_dict, special_sql_dict = condition_operation.\
-                    conditional_operation_by_one(condition, vertexes)
+                    conditional_operation_by_one(condition, vertexes, start_time, end_time)
                 if "sql" in special_sql_dict:
                     res = execute_graph_sql(graph, special_sql_dict.get("sql"), type=condition.get("type"))
                     rest.append(res)
