@@ -206,7 +206,7 @@ class ConditionOperation(object):
 
         return sql
 
-    def conditional_operation_by_one(self, condition, schemas={}):
+    def conditional_operation_by_one(self, condition, schemas={}, start_time = None, end_time = None):
         """
         合并conditional条件
         """
@@ -217,43 +217,20 @@ class ConditionOperation(object):
         val = None
         node_type = condition.get("type")
         schema = schemas.get(node_type)
-        src_nodes = condition.get("srcNodes")
-        if src_nodes:
-            if "src" in schema:
-                if schema["src_data_type"] == self.attribute_type_num:
-                    src_node = ",".join(src_nodes)
-                else:
-                    src_node = for_each_string_array_2_string(src_nodes)
-                if val:
-                    val = val + schema["src"] + " in(" + src_node + ") and "
-                else:
-                    val = " where " + schema["src"] + " in(" + src_node + ") and "
-
-        dest_nodes = condition.get("destNodes")
-        if dest_nodes:
-            if "dst" in schema:
-                if schema["dst_data_type"] == self.attribute_type_num:
-                    dest_node = ",".join(dest_nodes)
-                else:
-                    dest_node = for_each_string_array_2_string(dest_nodes)
-                if val:
-                    val = val + schema["dst"] + " in(" + dest_node + ") and "
-                else:
-                    val = " where " + schema["dst"] + " in(" + dest_node + ") and "
-
-        _id = condition.get("id")
-        if _id:
-            if "id" in schema:
-                if schema["id_data_type"] == self.attribute_type_num:
-                    ids = ",".join(_id)
-                else:
-                    ids = for_each_string_array_2_string(_id)
-                if val:
-                    val = val + schema["id"] + " in(" + ids + ") and "
-                else:
-                    val = " where " + schema["id"] + " in(" + ids + ") and "
-
         sub_conditions = condition.get("conditions")
+
+        if start_time:
+            for condition in sub_conditions:
+                if val:
+                    val = val + " and " + condition["attribute"] + " = \"" + start_time +"\" "
+                else:
+                    val = " where " + condition["attribute"] + " = \"" + start_time +"\" "
+        if end_time:
+            for condition in sub_conditions:
+                if val:
+                    val = val + " and " + condition["attribute"] + " = \"" + end_time +"\" "
+                else:
+                    val = " where " + condition["attribute"] + " = \"" + end_time +"\" "
         val_sql = val
         val_dict = self.splice_condition(sub_conditions, schema, val_sql)
         if "sql" in val_dict:
