@@ -1,4 +1,6 @@
+import os
 import time
+import gzip
 import numpy as np
 
 
@@ -26,5 +28,16 @@ def tostr(obj):
     if type(obj) == list:
         return str(obj)
     elif type(obj) == np.ndarray:
-        return np.array2string(obj, separator=',', threshold=1000000000, max_line_width=1000000000)
+        return np.array2string(obj, separator=',', threshold=1000000000,
+                               max_line_width=1000000000)
+
+
+def unzip_file(file_path, file_name):
+    new_file_name = file_name.replace(".gz", "")
+    gzip_file = gzip.GzipFile(os.path.join(file_path, file_name))
+    with open(os.path.join(file_path, new_file_name), "wb+") as f:
+        f.write(gzip_file.read())
+
+    return os.path.join(file_path, new_file_name)
+
 
